@@ -1,4 +1,4 @@
-utils::globalVariables(c("silentText","silentGraph","silentLegend","initialType"));
+utils::globalVariables(c("silentText","silentGraph","silentLegend","initialType","yForecastStart"));
 
 #' Complex Exponential Smoothing
 #'
@@ -518,8 +518,9 @@ CreatorCES <- function(silentText=FALSE,...){
     if(obsNonzero <= nParamMax){
         if(xregDo=="select"){
             if(obsNonzero <= (nParamMax - nParamExo)){
-                stop(paste0("Not enough observations for the reasonable fit. Number of parameters is ",
+                warning(paste0("Not enough observations for the reasonable fit. Number of parameters is ",
                             nParamMax," while the number of observations is ",obsNonzero - nParamExo,"!"),call.=FALSE);
+                tinySample <- TRUE;
             }
             else{
                 warning(paste0("The potential number of exogenous variables is higher than the number of observations. ",
@@ -527,10 +528,28 @@ CreatorCES <- function(silentText=FALSE,...){
             }
         }
         else{
-            stop(paste0("Not enough observations for the reasonable fit. Number of parameters is ",
-                        nParamMax," while the number of observations is ",obsNonzero,"!"),call.=FALSE);
+            warning(paste0("Not enough observations for the reasonable fit. Number of parameters is ",
+                           nParamMax," while the number of observations is ",obsNonzero,"!"),call.=FALSE);
+            tinySample <- TRUE;
         }
     }
+    else{
+        tinySample <- FALSE;
+    }
+
+# If this is tiny sample, use SES instead
+    if(tinySample){
+        warning("Not enough observations to fit CES. Switching to ETS(A,N,N).",call.=FALSE);
+        return(es(data,"ANN",initial=initial,cfType=cfType,
+                  h=h,holdout=holdout,cumulative=cumulative,
+                  intervals=intervals,level=level,
+                  intermittent=intermittent,
+                  imodel=imodel,
+                  bounds="u",
+                  silent=silent,
+                  xreg=xreg,xregDo=xregDo,initialX=initialX,
+                  updateX=updateX,persistenceX=persistenceX,transitionX=transitionX));
+    }
 
 ##### Start doing things #####
     environment(intermittentParametersSetter) <- environment();
@@ -703,7 +722,7 @@ CreatorCES <- function(silentText=FALSE,...){
     parametersNumber[1,1] <- parametersNumber[1,1] + 1;
 
     # Write down the probabilities from intermittent models
-    pt <- ts(c(as.vector(pt),as.vector(pt.for)),start=start(data),frequency=datafreq);
+    pt <- ts(c(as.vector(pt),as.vector(pt.for)),start=dataStart,frequency=datafreq);
     # Write down the number of parameters of imodel
     if(all(intermittent!=c("n","provided")) & !imodelProvided){
         parametersNumber[1,3] <- imodel$nParam;
@@ -780,16 +799,16 @@ CreatorCES <- function(silentText=FALSE,...){
     parametersNumber[2,4] <- sum(parametersNumber[2,1:3]);
 
     if(holdout){
-        y.holdout <- ts(data[(obsInsample+1):obsAll],start=start(y.for),frequency=datafreq);
+        y.holdout <- ts(data[(obsInsample+1):obsAll],start=yForecastStart,frequency=datafreq);
         if(cumulative){
-            errormeasures <- errorMeasurer(sum(y.holdout),y.for,h*y);
+            errormeasures <- Accuracy(sum(y.holdout),y.for,h*y);
         }
         else{
-            errormeasures <- errorMeasurer(y.holdout,y.for,y);
+            errormeasures <- Accuracy(y.holdout,y.for,y);
         }
 
         if(cumulative){
-            y.holdout <- ts(sum(y.holdout),start=start(y.for),frequency=datafreq);
+            y.holdout <- ts(sum(y.holdout),start=yForecastStart,frequency=datafreq);
         }
     }
     else{
@@ -816,10 +835,10 @@ CreatorCES <- function(silentText=FALSE,...){
         y.high.new <- y.high;
         y.low.new <- y.low;
         if(cumulative){
-            y.for.new <- ts(rep(y.for/h,h),start=start(y.for),frequency=datafreq)
+            y.for.new <- ts(rep(y.for/h,h),start=yForecastStart,frequency=datafreq)
             if(intervals){
-                y.high.new <- ts(rep(y.high/h,h),start=start(y.for),frequency=datafreq)
-                y.low.new <- ts(rep(y.low/h,h),start=start(y.for),frequency=datafreq)
+                y.high.new <- ts(rep(y.high/h,h),start=yForecastStart,frequency=datafreq)
+                y.low.new <- ts(rep(y.low/h,h),start=yForecastStart,frequency=datafreq)
             }
         }
 
