@@ -1,5 +1,6 @@
 utils::globalVariables(c("normalizer","constantValue","constantRequired","constantEstimate","C",
-                         "ARValue","ARRequired","AREstimate","MAValue","MARequired","MAEstimate"));
+                         "ARValue","ARRequired","AREstimate","MAValue","MARequired","MAEstimate",
+                         "yForecastStart"));
 
 #' State-Space ARIMA
 #'
@@ -555,8 +556,9 @@ CreatorSSARIMA <- function(silentText=FALSE,...){
     if(obsNonzero <= nParamMax){
         if(xregDo=="select"){
             if(obsNonzero <= (nParamMax - nParamExo)){
-                stop(paste0("Not enough observations for the reasonable fit. Number of parameters is ",
-                            nParamMax," while the number of observations is ",obsNonzero - nParamExo,"!"),call.=FALSE);
+                warning(paste0("Not enough observations for the reasonable fit. Number of parameters is ",
+                               nParamMax," while the number of observations is ",obsNonzero - nParamExo,"!"),call.=FALSE);
+                tinySample <- TRUE;
             }
             else{
                 warning(paste0("The potential number of exogenous variables is higher than the number of observations. ",
@@ -564,10 +566,31 @@ CreatorSSARIMA <- function(silentText=FALSE,...){
             }
         }
         else{
-            stop(paste0("Not enough observations for the reasonable fit. Number of parameters is ",
-                        nParamMax," while the number of observations is ",obsNonzero,"!"),call.=FALSE);
+            warning(paste0("Not enough observations for the reasonable fit. Number of parameters is ",
+                           nParamMax," while the number of observations is ",obsNonzero,"!"),call.=FALSE);
+            tinySample <- TRUE;
         }
     }
+    else{
+        tinySample <- FALSE;
+    }
+
+
+# If this is tiny sample, use ARIMA with constant instead
+    if(tinySample){
+        warning("Not enough observations to fit ARIMA. Switching to ARIMA(0,0,0) with constant.",call.=FALSE);
+        return(ssarima(data,orders=list(ar=0,i=0,ma=0),lags=1,
+                       constant=TRUE,
+                       initial=initial,cfType=cfType,
+                       h=h,holdout=holdout,cumulative=cumulative,
+                       intervals=intervals,level=level,
+                       intermittent=intermittent,
+                       imodel=imodel,
+                       bounds="u",
+                       silent=silent,
+                       xreg=xreg,xregDo=xregDo,initialX=initialX,
+                       updateX=updateX,persistenceX=persistenceX,transitionX=transitionX));
+    }
 
 #####Start the calculations#####
     environment(intermittentParametersSetter) <- environment();
@@ -766,7 +789,7 @@ CreatorSSARIMA <- function(silentText=FALSE,...){
     parametersNumber[1,1] <- parametersNumber[1,1] + 1;
 
     # Write down the probabilities from intermittent models
-    pt <- ts(c(as.vector(pt),as.vector(pt.for)),start=start(data),frequency=datafreq);
+    pt <- ts(c(as.vector(pt),as.vector(pt.for)),start=dataStart,frequency=datafreq);
     # Write down the number of parameters of imodel
     if(all(intermittent!=c("n","provided")) & !imodelProvided){
         parametersNumber[1,3] <- imodel$nParam;
@@ -863,16 +886,16 @@ CreatorSSARIMA <- function(silentText=FALSE,...){
     }
 
     if(holdout==T){
-        y.holdout <- ts(data[(obsInsample+1):obsAll],start=start(y.for),frequency=frequency(data));
+        y.holdout <- ts(data[(obsInsample+1):obsAll],start=yForecastStart,frequency=frequency(data));
         if(cumulative){
-            errormeasures <- errorMeasurer(sum(y.holdout),y.for,h*y);
+            errormeasures <- Accuracy(sum(y.holdout),y.for,h*y);
         }
         else{
-            errormeasures <- errorMeasurer(y.holdout,y.for,y);
+            errormeasures <- Accuracy(y.holdout,y.for,y);
         }
 
         if(cumulative){
-            y.holdout <- ts(sum(y.holdout),start=start(y.for),frequency=datafreq);
+            y.holdout <- ts(sum(y.holdout),start=yForecastStart,frequency=datafreq);
         }
     }
     else{
@@ -936,10 +959,10 @@ CreatorSSARIMA <- function(silentText=FALSE,...){
         y.high.new <- y.high;
         y.low.new <- y.low;
         if(cumulative){
-            y.for.new <- ts(rep(y.for/h,h),start=start(y.for),frequency=datafreq)
+            y.for.new <- ts(rep(y.for/h,h),start=yForecastStart,frequency=datafreq)
             if(intervals){
-                y.high.new <- ts(rep(y.high/h,h),start=start(y.for),frequency=datafreq)
-                y.low.new <- ts(rep(y.low/h,h),start=start(y.for),frequency=datafreq)
+                y.high.new <- ts(rep(y.high/h,h),start=yForecastStart,frequency=datafreq)
+                y.low.new <- ts(rep(y.low/h,h),start=yForecastStart,frequency=datafreq)
             }
         }
 
